Obiter.Ai
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Computational methods and artificial intelligence will transform the
study and practice of law by significantly expanding the reach of
empirical enquiries.

<div class="column-margin">

<figure>
<img src="images/computer_calls.png"
data-fig-alt="&quot;Computer calls a database,&quot; AI artist (2022)"
alt="“A computer calls a database,” AI artist (2022)" />
<figcaption aria-hidden="true">“A computer calls a database,” AI artist
(2022)</figcaption>
</figure>

</div>

The volume of legal data increased exponentially over the past decades.
In Canada, an average size tribunal will issue tens of millions of words
each year. Thousands of hours of proceedings will be recorded. Trillions
of words will be filed as evidence.

Making sense of, and understanding this data, is a pressing challenge
for scholars and lawyers. Is the law consistent? Do different
adjudicators reach similiar conclusions when presented with similiar
facts? What types of disputes are people bringing to decision makers?
How are those disputes resolved?

Answering these questions at scale exceeds human capacities. Consider
this example. In 2021, the [Ontario Workplace Safety and Insurance
Appeals Tribunal](https://www.wsiat.on.ca/en/home/announcements.html),
issued [2,053 written
decisions](https://www.canlii.org/en/on/onwsiat/nav/date/2021/). If each
decision averages 2,500 words in length, the tribunal outputted
5,132,500 words—the equivalent of 9 editions of *War and Peace*. The
volume of data means that the jurisprudence regarding workers,
disability, and compensation cannot be comprehensively grasped or
synthesized by researchers. Who could ever read so much?

But computers are not so limited. Recent advances in artificial
intelligence and machine learning have significantly expanded machines’
ability to understand, organize, and sythesize complex data. Computers
can now credibly answer complex questions about documents, detect
patterns, and reason with facts.

Lawyers, law students, and researchers should understand how these
methods can be leveraged for research at scale. The goal of
**Obiter.Ai** is to build out a suite of open source and accessible
computational tools to facilitate computational research of Canadian
law.
